==> apache-camel-4.8.9-src.zip: apache-camel-4.8.9/components/camel-olingo2/camel-olingo2-component/src/main/java/org/apache/camel/component/olingo2/internal/Olingo2PropertiesHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.olingo2.internal;

import org.apache.camel.CamelContext;
import org.apache.camel.component.olingo2.Olingo2Configuration;
import org.apache.camel.support.component.ApiMethodPropertiesHelper;

/**
 * Singleton {@link ApiMethodPropertiesHelper} for Olingo2 component.
 */
public final class Olingo2PropertiesHelper extends ApiMethodPropertiesHelper<Olingo2Configuration> {

    private static Olingo2PropertiesHelper helper;

    private Olingo2PropertiesHelper(CamelContext context) {
        super(context, Olingo2Configuration.class, Olingo2Constants.PROPERTY_PREFIX);
    }

    public static synchronized Olingo2PropertiesHelper getHelper(CamelContext context) {
        if (helper == null) {
            helper = new Olingo2PropertiesHelper(context);
        }
        return helper;
    }
}

==> apache-camel-4.15.0-src.zip: apache-camel-4.15.0/components/camel-olingo2/camel-olingo2-component/src/main/java/org/apache/camel/component/olingo2/internal/Olingo2PropertiesHelper.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.olingo2.internal;

import java.util.concurrent.locks.Lock;
import java.util.concurrent.locks.ReentrantLock;

import org.apache.camel.CamelContext;
import org.apache.camel.component.olingo2.Olingo2Configuration;
import org.apache.camel.support.component.ApiMethodPropertiesHelper;

/**
 * Singleton {@link ApiMethodPropertiesHelper} for Olingo2 component.
 */
public final class Olingo2PropertiesHelper extends ApiMethodPropertiesHelper<Olingo2Configuration> {

    private static final Lock LOCK = new ReentrantLock();
    private static Olingo2PropertiesHelper helper;

    private Olingo2PropertiesHelper(CamelContext context) {
        super(context, Olingo2Configuration.class, Olingo2Constants.PROPERTY_PREFIX);
    }

    public static Olingo2PropertiesHelper getHelper(CamelContext context) {
        LOCK.lock();
        try {
            if (helper == null) {
                helper = new Olingo2PropertiesHelper(context);
            }
            return helper;
        } finally {
            LOCK.unlock();
        }
    }
}
